# Getting started with conditionals

In the example above,
we made it possible to rename the "new" function
generated by our template.
But our approach is flawed:
if the user _doesn't_ provide
the `#[deftly(newfn)]` attribute,
the template won't make a function name at all!

Let's show how to fix that:
```
# use derive_deftly::define_derive_deftly;
define_derive_deftly! {
   Constructor for struct:

   impl<$tgens> $ttype where $twheres {
   pub fn
        ${if tmeta(newfn) { ${tmeta(newfn)} } else { new } } // (1)
     ( $( $fname: $ftype , ) ) -> Self {
          Self {
              $( $fname , )
          }
      }
   }
}
```

Have a look at the line marked with `// (1)`.
It introduces a new concept: _conditional expansion_.
The
[`${if ...}`][x:if]
keyword checks whether a given _condition_ is true.
If it is, then it expands to one of its arguments.
Otherwise, it expands to an "else" argument (if any).

> Also, you can chain `$if`s, as in
> `${if COND1 { ... } else if COND2 { ... } else { ... }`
> and so on!

Here, the condition is
[`tmeta(newfn)`][c:tmeta]
That condition is true if the current type
has an `#[deftly(newfn)]` attribute,
and false otherwise.
There are also `vmeta` and `fmeta` attributes
to detect `#[deftly(..)]` attributes
on variants and fields respectively.

[x:if]: https://docs.rs/derive-deftly/latest/derive_deftly/doc_reference/index.html#x:if
[c:tmeta]: https://docs.rs/derive-deftly/latest/derive_deftly/doc_reference/index.html#c:tmeta

